Welcome to Charlatan’s documentation! — charlatan 0.3.2 documentation

### Navigation

- index
- modules |
- next |
- charlatan 0.3.2 documentation »

# Welcome to Charlatan’s documentation!

Efficiently manage and install data fixtures

Charlatan is a library that you can use in your tests to create database fixtures. Its aim is to provide a pragmatic interface that focuses on making it simple to define and install fixtures for your tests. It is also agnostic in so far as even though it’s designed to work out of the box with SQLAlchemy models, it can work with pretty much anything else.

## Contents

- Quickstart
  - A simple example
  - Using charlatan in test cases
  - Using fixtures
- File format
  - Defining a fixture
  - Inheritance
  - Having dictionaries as fixtures
  - Getting an already existing fixture from the database
  - Dependencies
  - Post creation
  - Linking to other objects
  - Collections of Fixtures
  - Relative timestamps
- Hooks
- API Reference
  - FixturesManager
  - FixturesManagerMixin
  - Fixture
  - Utils
- Contributing
- Changelog for Charlatan
  - 0.3.2 (2014-01-16)
  - 0.3.1 (2014-01-10)
  - 0.2.9 (2013-11-20)
  - 0.2.8 (2013-11-12)
  - 0.2.7 (2013-10-24)
  - 0.2.6 (2013-09-06)
  - 0.2.5 (2013-09-06)
  - 0.2.4 (2013-08-08)
  - 0.2.3 (2013-06-28)
  - 0.1.2 (2013-04-01)

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- charlatan 0.3.2 documentation »